@@ -35,7 +35,7 @@ Predictor <- R6::R6Class(
         # Create handle on it
         handle <- .Call(
           LGBM_BoosterCreateFromModelfile_R
-          , modelfile
+          , path.expand(modelfile)
         )
         private$need_free_handle <- TRUE
 
@@ -96,6 +96,8 @@ Predictor <- R6::R6Class(
       # Check if data is a file name and not a matrix
       if (identical(class(data), "character") && length(data) == 1L) {
 
+        data <- path.expand(data)
+
         # Data is a filename, create a temporary file with a "lightgbm_" pattern in it
         tmp_filename <- tempfile(pattern = "lightgbm_")
         on.exit(unlink(tmp_filename), add = TRUE)
